/**
 * Copyright (c) 2010-2020 Contributors to the openHAB project
 *
 * See the NOTICE file(s) distributed with this work for additional
 * information.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0
 *
 * SPDX-License-Identifier: EPL-2.0
 */
package org.openhab.binding.ecobee.internal.dto.thermostat;

import java.util.List;

/**
 * The {@link NotificationSettingsDTO} contains the configuration of the possible alerts and
 * reminders which can be generated by the Thermostat. The NotificationsSettings supports
 * retrieval through a Thermostat GET call, setting the includeNotificationSettings to
 * true in the Selection.
 *
 * @author Mark Hilbush - Initial contribution
 */
public class NotificationSettingsDTO {

    /*
     * The list of email addresses alerts and reminders will be sent to.
     * The full list of email addresses must be sent in any update request.
     * If any are missing from that list they will be deleted. If an empty
     * list is sent, any email addresses will be deleted.
     */
    public List<String> emailAddresses;

    /*
     * Boolean values representing whether or not alerts and reminders
     * will be sent to the email addresses listed above when triggered.
     */
    public Boolean emailNotificationsEnabled;

    /*
     * The list of equipment specific alert and reminder settings.
     */
    public List<EquipmentSettingDTO> equipment;

    /*
     * The list of general alert and reminder settings.
     */
    public List<GeneralSettingDTO> general;

    /*
     * The list of limit specific alert and reminder settings.
     */
    public List<LimitSettingDTO> limit;
}
