/**
 * Copyright (c) 2010-2020 Contributors to the openHAB project
 *
 * See the NOTICE file(s) distributed with this work for additional
 * information.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0
 *
 * SPDX-License-Identifier: EPL-2.0
 */
package org.openhab.binding.modbus.e3dc.util;

import static org.junit.jupiter.api.Assertions.assertEquals;

import java.nio.ByteBuffer;
import java.util.BitSet;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.junit.jupiter.api.Test;
import org.openhab.binding.modbus.e3dc.internal.dto.DataConverter;

/**
 * The {@link DataConverterTest} Test data conversions
 *
 * @author Bernd Weymann - Initial contribution
 */
@NonNullByDefault
public class DataConverterTest {

    @Test
    public void testE3DCSwapValueNegative() {
        // Reg 69 value 65098 bytes [-2, 74]
        // Reg 70 value 65535 bytes [-1, -1]
        byte[] b = new byte[] { -2, -74, -1, -1 };
        assertEquals(-330, DataConverter.getInt32Swap(ByteBuffer.wrap(b)), "Negative Value");
    }

    @Test
    public void testBitset() {
        byte[] b = new byte[] { 3, 16 };
        BitSet s = BitSet.valueOf(b);
        assertEquals(true, s.get(0), "Bit0");
        assertEquals(true, s.get(1), "Bit1");
        assertEquals(false, s.get(2), "Bit2");
        assertEquals(false, s.get(3), "Bit3");
        assertEquals(false, s.get(4), "Bit4");
        assertEquals(false, s.get(5), "Bit5");
        assertEquals(false, s.get(6), "Bit6");
        assertEquals(false, s.get(7), "Bit7");
        assertEquals(false, s.get(8), "Bit8");
        assertEquals(false, s.get(9), "Bit9");
        assertEquals(false, s.get(10), "Bit10");
        assertEquals(false, s.get(11), "Bit11");
        assertEquals(true, s.get(12), "Bit12");
        assertEquals(false, s.get(13), "Bit13");
        assertEquals(false, s.get(14), "Bit14");
        assertEquals(false, s.get(15), "Bit15");
    }
}
