/**
 * Copyright (c) 2010-2020 Contributors to the openHAB project
 *
 * See the NOTICE file(s) distributed with this work for additional
 * information.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0
 *
 * SPDX-License-Identifier: EPL-2.0
 */
package org.openhab.binding.remoteopenhab.internal.listener;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;
import org.openhab.binding.remoteopenhab.internal.data.RemoteopenhabStatusInfo;
import org.openhab.binding.remoteopenhab.internal.data.RemoteopenhabThing;
import org.openhab.binding.remoteopenhab.internal.rest.RemoteopenhabRestClient;

/**
 * Interface for listeners of events relative to things generated by the {@link RemoteopenhabRestClient}.
 *
 * @author Laurent Garnier - Initial contribution
 */
@NonNullByDefault
public interface RemoteopenhabThingsDataListener {

    /**
     * A new ThingStatusInfoChangedEvent was published.
     */
    void onThingStatusUpdated(String thingUID, RemoteopenhabStatusInfo statusInfo);

    /**
     * A new ThingAddedEvent was published.
     */
    void onThingAdded(RemoteopenhabThing thing);

    /**
     * A new ThingRemovedEvent was published.
     */
    void onThingRemoved(RemoteopenhabThing thing);

    /**
     * A new ChannelTriggeredEvent was published.
     */
    void onChannelTriggered(String channelUID, @Nullable String event);
}
